@@ -1,7 +1,7 @@
 package Complete::Getopt::Long;
 
 our $DATE = '2015-09-17'; # DATE
-our $VERSION = '0.35'; # VERSION
+our $VERSION = '0.36'; # VERSION
 
 use 5.010001;
 use strict;
@@ -17,6 +17,10 @@ our @EXPORT_OK = qw(
 our %SPEC;
 
 sub _default_completion {
+    require Complete::Env;
+    require Complete::File;
+    require Complete::Util;
+
     my %args = @_;
     my $word = $args{word} // '';
 
@@ -26,9 +30,8 @@ sub _default_completion {
     # try completing '$...' with shell variables
     if ($word =~ /\A\$/) {
         $log->tracef('[comp][compgl] completing shell variable');
-        require Complete::Util;
         {
-            my $compres = Complete::Util::complete_env(
+            my $compres = Complete::Env::complete_env(
                 word=>$word);
             last unless @$compres;
             $fres = {words=>$compres, esc_mode=>'shellvar'};
@@ -85,7 +88,7 @@ sub _default_completion {
         # if empty, fallback to searching file
     }
     $log->tracef("[comp][compgl] completing with file, file=<%s>", $word);
-    $fres = {words=>Complete::Util::complete_file(word=>$word),
+    $fres = {words=>Complete::File::complete_file(word=>$word),
              path_sep=>'/'};
   RETURN_RES:
     $log->tracef("[comp][compgl] leaving default completion routine, result=%s", $fres);
@@ -584,7 +587,7 @@ Complete::Getopt::Long - Complete command-line argument using Getopt::Long speci
 
 =head1 VERSION
 
-This document describes version 0.35 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2015-09-17.
+This document describes version 0.36 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2015-09-17.
 
 =head1 SYNOPSIS
 
